# PWE-NB-Extension
Notebook Extension for PWE

After installing this package via [PyPi](https://pypi.org/project/PWE-NB-Extension/), execute the following in your jupyter notebook to activate this extension:

```%load_ext PWE_NB_Extension```

#### Acknowledgement:
Prolog Syntax Highlighting code for Codemirror found [here](https://github.com/SWI-Prolog/swish/tree/master/web/js/codemirror/mode/prolog)
